==> moodle-4.4.2.tgz: share/moodle/lib/editor/tiny/plugins/h5p/lang/en/tiny_h5p.php <==
<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'tiny_h5p', language 'en'.
 *
 * @package    tiny_h5p
 * @copyright  2022 Andrew Lyons <andrew@nicols.co.uk>
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['helplinktext'] = 'H5P helper';
$string['modaltitle'] = 'Insert H5P content';
$string['buttontitle'] = 'Configure H5P content';
$string['insert'] = 'Insert H5P content';
$string['pluginname'] = 'Insert H5P';
$string['browserepositories'] = 'Browse repositories...';
$string['copyrightbutton'] = 'Copyright button';
$string['downloadbutton'] = 'Allow download';
$string['embedbutton'] = 'Embed button';
$string['h5p:addembed'] = 'Add embedded H5P';
$string['h5pfile'] = 'H5P file upload';
$string['h5pfileorurl'] = 'H5P URL or file upload';
$string['h5poptions'] = 'H5P options';
$string['h5purl'] = 'H5P URL';
$string['invalidh5purl'] = 'Invalid URL';
$string['instructions'] = 'You can insert H5P content by <strong>either</strong> entering a URL <strong>or</strong> by uploading an H5P file.';
$string['noh5pcontent'] = 'No H5P content added';
$string['privacy:metadata'] = 'The H5P plugin for TinyMCE does not store any personal data.';

==> moodle-5.0.1.tgz: share/moodle/lib/editor/tiny/plugins/h5p/lang/en/tiny_h5p.php <==
<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'tiny_h5p', language 'en'.
 *
 * @package    tiny_h5p
 * @copyright  2022 Andrew Lyons <andrew@nicols.co.uk>
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['modaltitle'] = 'Insert H5P content';
$string['buttontitle'] = 'Insert H5P content';
$string['insert'] = 'Insert H5P content';
$string['pluginname'] = 'Insert H5P';
$string['browserepositories'] = 'Browse repositories...';
$string['copyrightbutton'] = 'Copyright button';
$string['displayoptions'] = 'Display options';
$string['downloadbutton'] = 'Allow download';
$string['embedbutton'] = 'Embed button';
$string['h5p:addembed'] = 'Add embedded H5P';
$string['h5p:use'] = 'Use TinyMCE H5P';
$string['h5pfile'] = 'H5P file upload';
$string['h5pfileorurl'] = 'H5P URL or file upload';
$string['h5poptions'] = 'H5P options';
$string['h5purl'] = 'H5P URL';
$string['invalidh5purl'] = 'Invalid URL';
$string['instructions'] = 'You can insert H5P content by <strong>either</strong> entering a URL <strong>or</strong> by uploading an H5P file.';
$string['mobileappautoplay'] = 'Auto-play in the mobile app';
$string['noh5pcontent'] = 'No H5P content added';
$string['privacy:metadata'] = 'The H5P plugin for TinyMCE does not store any personal data.';

// Deprecated since Moodle 4.5.
$string['helplinktext'] = 'H5P helper';
